@@ -8,7 +8,7 @@ class mom(Actor):
         self._num_children = 0
 
     def action(self):
-        c = child(at=self.timeline.now, step=1, till=8, priority=-self._num_children, name=f"Child-{self._num_children}")
+        c = child(at=self.timeline.now, step=1, till=10, priority=-self._num_children, name=f"Child-{self._num_children}")
         self._num_children += 1
         print(f"Time: {Mundus.now}\tEvent Priority: {self.priority}:\t{self._name} picks up a child {c._name}.")
 
@@ -19,15 +19,17 @@ class child(Actor):
         self._name = name
 
     def action(self):
-        if self.timeline.now >= 7:
-            uncle.deactivate()
         print(f"Time: {Mundus.now}\tEvent Priority: {self.priority}:\t{self._name}\tis playing at home.")
+        if self.timeline.now >= 5 and self.timeline.now<7:
+            uncle.deactivate()
+        if self.timeline.now >= 7:
+            uncle.activate()
 
-m = mom(at=0, step=1, till=5, priority=0, name="Mom")
+m = mom(at=0, step=1, till=3, priority=0, name="Mom")
 father = Actor(after=m, priority=-1, action=lambda: print(f"Time: {Mundus.now}\tEvent Priority: {father.priority}:\tFather comes back home."))
 uncle = Actor(after=father, step=1, till=10, priority=0, action=lambda: print(f"Time: {Mundus.now}\tEvent Priority: {uncle.priority}:\tUncle comes to vist."))
 
-Mundus.simulate(10)
+Mundus.simulate(3)
 print(m.status)
 print(father.status)
 print(uncle.status)
